@@ -2,33 +2,33 @@
 
 
 #' Class to store lowered-adp data
-#' 
+#'
 #' Class to store data measured with a lowered ADP (also
 #' known as ADCP) device.
-#' 
+#'
 #' @section Accessing data:
-#' 
+#'
 #'     Consider an object named \code{ladp}.
-#' 
+#'
 #'     Metadata (contained in the S4 slot named \code{metadata}) may be retrieved
 #'     or set by name, \code{ladp[["longitude"]] <- ladp[["longitude"]] + 1}
 #'     corrects a one-degree error.  Use \code{names(ladp@@metadata)} to find the
 #'     names of the metadata.
-#' 
+#'
 #'     Column data may be accessed by name, e.g. \code{ladp[["u"]]},
 #'     \code{ladp[["v"]]}, \code{ladp[["pressure"]]}, etc.  There may also be
 #'     columns for \code{"temperature"} and \code{"salinity"}, and possibly other
 #'     things. Use \code{names(ladp@@data)} to find the names of the data.
-#' 
+#'
 #' @author Dan Kelley
-#' 
+#'
 #' @family things related to \code{ladp} data
 setClass("ladp", contains="oce")
 
 setMethod(f="initialize",
           signature="ladp",
-          definition=function(.Object,longitude,latitude,station,waterDepth,time,
-                              pressure,u,v,salinity,temperature, ...) {
+          definition=function(.Object, longitude, latitude, station, waterDepth, time,
+                              pressure, u, v, salinity, temperature, ...) {
               ## Assign to some columns so they exist if needed later (even if they are NULL)
               .Object@metadata$longitude <- if (missing(longitude)) "?" else longitude
               .Object@metadata$latitude <- if (missing(latitude)) "?" else latitude
@@ -53,26 +53,26 @@ setMethod(f="initialize",
 
 
 #' Summarize an ladp object
-#' 
+#'
 #' Pertinent summary information is presented, including the station name,
 #' sampling location, data ranges, etc.
-#' 
+#'
 #' @param object An object of class \code{"ladp"}, usually, a result of a call to
 #' \code{\link{as.ladp}}.
-#' 
+#'
 #' @param ... Further arguments passed to or from other methods.
-#' 
+#'
 #' @return A matrix containing statistics of the elements of the \code{data} slot.
-#' 
+#'
 #' @author Dan Kelley
-#' 
+#'
 #' @family things related to \code{ladp} data
 setMethod(f="summary",
           signature="ladp",
           definition=function(object, ...) {
               cat("LADP Summary\n------------\n\n")
               showMetadataItem(object, "station", "Station:             ")
-              callNextMethod()
+              callNextMethod()         # summary
           })
 
 #' @title Extract Something From an ladp Object
@@ -101,25 +101,26 @@ setMethod(f="[[",
                   x@data$uz
               } else if (i == "vz") {
                   x@data$vz
-              } else if (i == "temperature" || i == "t") { # FIXME: document "t" part
+              } else if (i == "temperature" || i == "t") {
+                  ## FIXME: document "t" part
                   x@data$temperature
               } else if (i == "salinity" || i == "S") {
                   x@data$salinity
               } else {
-                  callNextMethod()
+                  callNextMethod()     # [[
               }
           })
 
 
 #' Plot an ladp object
-#' 
+#'
 #' Uses \code{\link{plotProfile}} to create panels of depth variation of easterly
 #' and northerly velocity components.
-#' 
+#'
 #' @param x A \code{ladp} object, e.g. as read by \code{\link{as.ladp}}.
 #' @param which Vector of names of items to be plotted.
 #' @param ... Other arguments, passed to plotting functions.
-#' 
+#'
 #' @author Dan Kelley
 #'
 #' @family things related to \code{ladp} data
@@ -131,7 +132,7 @@ setMethod(f="plot",
               for (w in which)
                   plotProfile(x, xtype=w, ...)
           })
- 
+
 fixColumn <- function(x) {
     x[!is.finite(x)] <- NA
     as.vector(x)
@@ -140,10 +141,10 @@ fixColumn <- function(x) {
 
 
 #' Coerce data into an ladp object
-#' 
+#'
 #' This function assembles vectors of pressure and velocity, possibly also with
 #' shears, salinity, temperature, etc.
-#' 
+#'
 #' @param longitude longitude in degrees east, or an \code{oce} object that
 #' contains the data otherwise given by \code{longitude} and the
 #' other arguments.
@@ -158,11 +159,11 @@ fixColumn <- function(x) {
 #' @param salinity salinity through the water column, in practical salinity units.
 #' @param temperature temperature through the water column.
 #' @param \dots optional additional data columns.
-#' 
+#'
 #' @return An object of \code{\link{ladp-class}}.
 #'
 #' @author Dan Kelley
-#' 
+#'
 #' @family things related to \code{ladp} data
 as.ladp <- function(longitude, latitude, station, time, pressure, u, v, uz, vz, salinity, temperature, ...)
 {
@@ -225,8 +226,7 @@ as.ladp <- function(longitude, latitude, station, time, pressure, u, v, uz, vz,
         temperature <- if (missing(temperature)) NULL else fixColumn(temperature)
     }
     res <- new("ladp", longitude=longitude, latitude=latitude, station=station, time=time,
-                pressure=pressure, u=u, v=v, uz=uz, vz=vz, salinity=salinity, temperature=temperature, ...)  
+                pressure=pressure, u=u, v=v, uz=uz, vz=vz, salinity=salinity, temperature=temperature, ...)
     res@metadata$waterDepth <- max(pressure, na.rm=TRUE)
     res
 }
-
