@@ -30,9 +30,9 @@ setClass("rsk", contains="oce")
 #' A sample \code{rsk} object derived from a Concerto CTD manufactured by RBR Ltd.
 #'
 #' @details The data were obtained September 2015, off the west coast
-#'     of Greenland, by Matt Rutherford and Nicole Trenholm of the
-#'     Ocean Research Project, in collaboration with RBR and with the
-#'     NASA Oceans Melting Greenland project.
+#' of Greenland, by Matt Rutherford and Nicole Trenholm of the
+#' Ocean Research Project, in collaboration with RBR and with the
+#' NASA Oceans Melting Greenland project.
 #'
 #' @name rsk
 #' @docType data
@@ -40,9 +40,9 @@ setClass("rsk", contains="oce")
 #' @examples
 #' library(oce)
 #' data(rsk)
+#' ## The object doesn't "know" it is CTD until told so
 #' plot(rsk)
 #' plot(as.ctd(rsk))
-#' plot(subset(as.ctd(rsk),pressure<10))
 #'
 #' @family datasets provided with \code{oce}
 #' @family things related to \code{rsk} data
@@ -156,6 +156,7 @@ setMethod(f="[[<-",
 #'
 #' @author Dan Kelley
 #' @family things related to \code{rsk} data
+#' @family functions that subset \code{oce} objects
 setMethod(f="subset",
           signature="rsk",
           definition=function(x, subset, ...) {
@@ -211,6 +212,13 @@ unitFromStringRsk <- function(s)
     ## "dbar" vs "dBar", both of which have been seen in files. Still, it
     ## was decided not to use ignore.case=TRUE in the grep() commands,
     ## because that seems to overly blunt the tool.
+    ##
+    ## Here's how to figure out special characters:
+    ## print(s)
+    ## [1] "µMol/m²/s"
+    ## Browse[1]> Encoding(s)<-"bytes"
+    ## Browse[2]> print(s)
+    ## [1] "\\xc2\\xb5Mol/m\\xc2\\xb2/s"
     if (1 == length(grep("mg/[lL]", s, useBytes=TRUE)))
         list(unit=expression(mg/l), scale="")
     else if (1 == length(grep("m[lL]/[lL]", s, useBytes=TRUE)))
@@ -233,6 +241,8 @@ unitFromStringRsk <- function(s)
         list(unit=expression(NTU), scale="")
     else if (1 == length(grep("\xB0", s, useBytes=TRUE)))
         list(unit=expression(degree*C), scale="ITS-90") # guessing on scale
+    else if (1 == length(grep("\\xc2\\xb5Mol/m\\xc2\\xb2/s", s, useBytes=TRUE))) # µMol/m²/s
+        list(unit=expression(mu*mol/m^2/s), scale="")
     else {
         warning("'", s, "' is not in the list of known .rsk units", sep="")
         list(unit=as.expression(s), scale="")
