@@ -1,7 +1,7 @@
 ## vim:textwidth=128:expandtab:shiftwidth=4:softtabstop=4
 
 #' @title Class to Store Windrose Data
-#' 
+#'
 #' @description
 #' Windrose objects store statistical information about winds, mainly for
 #' plotting as "wind rose" plots (see \code{\link{plot,windrose-method}}.
@@ -25,18 +25,18 @@ setMethod(f="initialize",
           })
 
 #' Summarize a \code{windrose} object
-#' 
+#'
 #' Summarizes some of the data in a \code{windrose} object.
 #'
 #' @param object An \code{windrose} object, i.e. inheriting from \code{\link{windrose-class}}.
-#' 
+#'
 #' @param ... Further arguments passed to or from other methods.
-#' 
+#'
 #' @seealso The documentation for \code{\link{windrose-class}} explains the structure
 #' of \code{windrose} objects, and also outlines the other functions dealing with them.
-#' 
+#'
 #' @author Dan Kelley
-#' 
+#'
 #' @family things related to \code{windrose} data
 setMethod(f="summary",
           signature="windrose",
@@ -44,8 +44,8 @@ setMethod(f="summary",
               cat("Windrose data\n-------------\n\n")
               n <- length(object@data$theta)
               dtheta <- abs(diff(object@data$theta[1:2]))
-              cat("* Have n=", n, "angles, separated by dtheta=", dtheta,"\n\n")
-              callNextMethod()
+              cat("* Have n=", n, "angles, separated by dtheta=", dtheta, "\n\n")
+              callNextMethod() # summary
           })
 
 
@@ -59,7 +59,7 @@ setMethod(f="summary",
 setMethod(f="[[",
           signature(x="windrose", i="ANY", j="ANY"),
           definition=function(x, i, j, ...) {
-              callNextMethod()
+              callNextMethod()         # [[
           })
 
 #' @title Replace Parts of a Windrose Object
@@ -68,33 +68,32 @@ setMethod(f="[[",
 #' @family things related to \code{windrose} data
 setMethod(f="[[<-",
           signature(x="windrose", i="ANY", j="ANY"),
-          definition=function(x, i, j, value) {
-              callNextMethod()
+          definition=function(x, i, j, ..., value) {
+              callNextMethod(x=x, i=i, j=j, ...=..., value=value) # [[<-
           })
 
 
 #' Create a Windrose Object
-#' 
+#'
 #' Create a wind-rose object, typically for plotting with
 #' \code{\link{plot,windrose-method}}.
-#' 
+#'
 #' @param x The x component of wind speed (or stress) \emph{or} an object of class
 #' \code{met} (see \code{\link{met-class}}), in which case the \code{u} and
 #' \code{v} components of that object are used for the components of wind speed,
 #' and \code{y} here is ignored.
-#' 
+#'
 #' @param y The y component of wind speed (or stress).
-#' 
+#'
 #' @param dtheta The angle increment (in degrees) within which to classify the data.
-#' 
+#'
 #' @param debug A flag that turns on debugging.  Set to 1 to get a moderate amount
 #' of debugging information, or to 2 to get more.
-#' 
-#' 
+#'
 #' @return An object of \code{\link{windrose-class}} that contains the standard
 #' \code{oce} slots named \code{data}, \code{metadata} and \code{proxessingLog}.
 #' The \code{data} slot contains
-#' 
+#'
 #' \describe{
 #'     \item{\code{n}}{the number of x values}
 #'     \item{\code{x.mean}}{the mean of the x values}
@@ -106,7 +105,7 @@ setMethod(f="[[<-",
 #'         observations in this class (the min, the lower hinge, the
 #'         median, the upper hinge, and the max)}
 #' }
-#' 
+#'
 #' @examples
 #' library(oce)
 #' xcomp <- rnorm(360) + 1
@@ -114,9 +113,9 @@ setMethod(f="[[<-",
 #' wr <- as.windrose(xcomp, ycomp)
 #' summary(wr)
 #' plot(wr)
-#' 
+#'
 #' @author Dan Kelley, with considerable help from Alex Deckmyn.
-#' 
+#'
 #' @family things related to \code{windrose} data
 as.windrose <- function(x, y, dtheta = 15, debug=getOption("oceDebug"))
 {
@@ -142,10 +141,10 @@ as.windrose <- function(x, y, dtheta = 15, debug=getOption("oceDebug"))
     theta <- seq(-pi+dt2, pi-dt2, length.out=nt)
     ## The bin-detection code was faulty until 2012-02-07.  This
     ## was pointed out by Alex Deckmyn, who also suggested the
-    ## present solution.  His issue reports, available on 
+    ## present solution.  His issue reports, available on
     ## github.com/dankelley/oce/issues, are a model of
     ## patience and insight.
-    ai <- 1 + floor((angle+pi)/dt)
+    ai <- 1 + floor( (angle+pi)/dt )
     ai <- (ai-1)%%nt + 1 # clean up problems (thanks, adeckmyn at github!!)
     if (min(ai) < 1)
         stop("problem setting up bins (ai<1)")
@@ -154,10 +153,10 @@ as.windrose <- function(x, y, dtheta = 15, debug=getOption("oceDebug"))
     for (i in 1:nt) {
         inside <- ai==i
         oceDebug(debug, sum(inside), "counts for angle category", i,
-                 "(", round(180/pi*(theta[i]-dt2), 4), "to", round(180/pi*(theta[i]+dt2), 4), "deg)\n")
+                 "(", round(180 / pi * (theta[i]-dt2), 4), "to", round(180 / pi * (theta[i]+dt2), 4), "deg)\n")
         count[i] <- sum(inside)
         mean[i] <- mean(R[inside], na.rm=TRUE)
-        fives[i,] <- fivenum(R[inside])
+        fives[i, ] <- fivenum(R[inside])
     }
     if (sum(count) != xlen)
         stop("miscount in angles")
@@ -172,28 +171,28 @@ as.windrose <- function(x, y, dtheta = 15, debug=getOption("oceDebug"))
 
 
 #' @title Plot Windrose data
-#' 
+#'
 #' @description
 #' Plot a \code{windrose} object, i.e. one inheriting from \code{\link{windrose-class}}.
 #'
 #' @param x A \code{windrose} object, e.g. inheriting from \code{\link{windrose-class}}.
-#' 
+#'
 #' @param type The thing to be plotted, either the number of counts in the angle
 #' interval, the mean of the values in the interval, the median of the values, or
 #' a \code{\link{fivenum}} representation of the values.
-#' 
+#'
 #' @param convention String indicating whether to use meteorological convention or
 #' oceanographic convention for the arrows that emanate from the centre of the
 #' rose.  In meteorological convenction, an arrow emanates towards the right on
 #' the diagram if the wind is from the east; in oceanographic convention, such an
 #' arrow indicates flow \emph{to} the east.
-#' 
+#'
 #' @param mgp Three-element numerical vector to use for \code{par(mgp)}, and also
 #' for \code{par(mar)}, computed from this.  The default is tighter than the R
 #' default, in order to use more space for the data and less for the axes.
-#' 
+#'
 #' @param mar Four-element numerical vector to be used with \code{\link{par}("mar")}.
-#' 
+#'
 #' @param col Optional list of colours to use.  If not set, the colours will be
 #' \code{c("red", "pink", "blue", "lightgray")}.  For the first three types of
 #' plot, the first colour in this list is used to fill in the rose, the third is
@@ -201,20 +200,20 @@ as.windrose <- function(x, y, dtheta = 15, debug=getOption("oceDebug"))
 #' \code{"fivenum"} type, the first colour is used for the inter-quartile range,
 #' the second is used outside this range, the third is used for the median, and
 #' the fourth is, again, used for the grid lines.
-#' 
+#'
 #' @param ... Optional arguments passed to plotting functions.
-#' 
+#'
 #' @examples
 #' library(oce)
 #' opar <- par(no.readonly = TRUE)
 #' xcomp <- rnorm(360) + 1
 #' ycomp <- rnorm(360)
 #' wr <- as.windrose(xcomp, ycomp)
-#' par(mfrow=c(1,2))
+#' par(mfrow=c(1, 2))
 #' plot(wr)
 #' plot(wr, "fivenum")
 #' par(opar)
-#' 
+#'
 #' @author Dan Kelley
 #'
 #' @family functions that plot \code{oce} data
@@ -222,7 +221,7 @@ as.windrose <- function(x, y, dtheta = 15, debug=getOption("oceDebug"))
 setMethod(f="plot",
           signature=signature("windrose"),
           definition=function(x,
-                              type=c("count","mean", "median", "fivenum"),
+                              type=c("count", "mean", "median", "fivenum"),
                               convention=c("meteorological", "oceanographic"),
                               mgp=getOption("oceMgp"),
                               mar=c(mgp[1], mgp[1], 1+mgp[1], mgp[1]),
@@ -276,7 +275,7 @@ setMethod(f="plot",
                       ##cat("t=", t[i], " r=", r, "\n")
                       xlist <- c(0, r * cos(t[i] - dt2), r * cos(t[i] + dt2), 0)
                       ylist <- c(0, r * sin(t[i] - dt2), r * sin(t[i] + dt2), 0)
-                      polygon(xlist, ylist,col=col[1], border=col[3])
+                      polygon(xlist, ylist, col=col[1], border=col[3])
                   }
                   title(paste("Counts (max ", max, ")", sep=""))
               } else if (type == "mean") {
@@ -286,21 +285,21 @@ setMethod(f="plot",
                       ##cat("t=", t[i], " r=", r, "\n")
                       xlist <- c(0, r * cos(t[i] - dt2), r * cos(t[i] + dt2), 0)
                       ylist <- c(0, r * sin(t[i] - dt2), r * sin(t[i] + dt2), 0)
-                      polygon(xlist, ylist,col=col[1], border=col[3])
+                      polygon(xlist, ylist, col=col[1], border=col[3])
                   }
                   title(paste("Means (max ", sprintf(max, fmt="%.3g"), ")", sep=""))
               } else if (type == "median") {
-                  max <- max(x@data$fives[,5], na.rm=TRUE)
+                  max <- max(x@data$fives[, 5], na.rm=TRUE)
                   for (i in 1:nt) {
-                      r <- x@data$fives[i,3] / max
+                      r <- x@data$fives[i, 3] / max
                       ##cat("t=", t[i], " r=", r, "\n")
                       xlist <- c(0, r * cos(t[i] - dt2), r * cos(t[i] + dt2), 0)
                       ylist <- c(0, r * sin(t[i] - dt2), r * sin(t[i] + dt2), 0)
-                      polygon(xlist, ylist,col=col[1], border=col[3])
+                      polygon(xlist, ylist, col=col[1], border=col[3])
                   }
-                  title(paste("Medians (max ", sprintf(max,fmt="%.3g"), ")", sep=""))
+                  title(paste("Medians (max ", sprintf(max, fmt="%.3g"), ")", sep=""))
               } else if (type == "fivenum") {
-                  max <- max(x@data$fives[,3], na.rm=TRUE)
+                  max <- max(x@data$fives[, 3], na.rm=TRUE)
                   for (i in 1:nt) {
                       for (j in 2:3) {
                           tm <- t[i] - dt2
@@ -309,15 +308,13 @@ setMethod(f="plot",
                           r  <- x@data$fives[i, j  ] / max
                           xlist <- c(r0 * cos(tm), r * cos(tm), r * cos(tp), r0 * cos(tp))
                           ylist <- c(r0 * sin(tm), r * sin(tm), r * sin(tp), r0 * sin(tp))
-                          thiscol <- col[c(2,1,1,2)][j-1]
+                          thiscol <- col[c(2, 1, 1, 2)][j-1]
                           polygon(xlist, ylist, col=thiscol, border=col[4])
                       }
                       r <- x@data$fivenum[i, 3] / max
                       lines(c(r * cos(tm), r * cos(tp)), c(r * sin(tm), r * sin(tp)), col="blue", lwd=2)
                   }
-                  title(paste("Fiveum (max ", sprintf(max,fmt="%.3g"), ")", sep=""))
+                  title(paste("Fiveum (max ", sprintf(max, fmt="%.3g"), ")", sep=""))
               }
               invisible()
           })
-
-
