@@ -1,13 +1,50 @@
 ## ---- echo = FALSE-------------------------------------------------------
 knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
 
+## ----eval=FALSE----------------------------------------------------------
+#  ?`[[,oce-method`
+
+## ----eval=FALSE----------------------------------------------------------
+#  ?`[[,ctd-method`
+
+## ----eval=FALSE----------------------------------------------------------
+#  S <- d[['salinity']]
+
+## ----eval=FALSE----------------------------------------------------------
+#  data <- d[['data']]
+
+## ----eval=FALSE----------------------------------------------------------
+#  data$temperature
+
+## ----eval=FALSE----------------------------------------------------------
+#  data(ctd)
+#  ctd[["temperatureAboveFreezing"]] <- ctd[["temperature"]] - swTFreeze(ctd)
+
+## ----eval=FALSE----------------------------------------------------------
+#  ?"[[<-,oce-method"
+
+## ----extractExample, eval=FALSE------------------------------------------
+#  ctd[["metadata"]]$scientist <- "Dalhousie Oceanography 4120/5120 Class of 2003"
+
+## ----eval=FALSE----------------------------------------------------------
+#  ctd <- oceSetMetadata(ctd, name="scientist",
+#                        value="Dalhousie Oceanography 4120/5120 Class of 2003",
+#                        note="give credit where it's due")
+
+## ----eval=FALSE----------------------------------------------------------
+#  ctd <- oceSetData(ctd, name="temperatureAboveFreezing",
+#                        value=ctd[["temperature"]] - swTFreeze(ctd),
+#                        unit=list(unit=expression(degree*C), scale="ITS-90"),
+#                        originalName="-",
+#                        note="add temperatureAboveFreezing, for ice-related calculations")
+
 ## ----eval=FALSE----------------------------------------------------------
 #  library(oce)
 #  d <- read.oce("station1.cnv")
 #  summary(d)
 #  plot(d)
 
-## ----fig.cap="**Figure 2.** An overview of a ctd dataset.", fig.width=6, fig.height=6, dpi=72, dev.args=list(pointsize=15), message=FALSE----
+## ----fig.cap="**Figure 2.** An overview of a ctd dataset.", fig.width=6, fig.height=6, dpi=72, dev.args=list(pointsize=14), message=FALSE----
 library(oce)
 data(ctd)
 summary(ctd)
@@ -48,18 +85,18 @@ plotScan(ctdRaw)
 #  data(section)
 #  plot(section, which=c(1, 2, 3, 99))
 
-## ----fig.cap="**Figure 4.** Portion of the CTD section designated A03, showing the Gulf Sream region.  The square on the cruise track corresponds to zero distance on the section.", fig.width=5, fig.height=5, dpi=72, dev.args=list(pointsize=12)----
+## ----fig.cap="**Figure 4.** Portion of the CTD section designated A03, showing the Gulf Sream region.  The square on the cruise track corresponds to zero distance on the section.", fig.width=4, fig.height=4, dpi=72, dev.args=list(pointsize=12)----
 library(oce)
 data(section)
 GS <- subset(section, 102 <= stationId & stationId <= 124)
 GSg <- sectionGrid(GS, p=seq(0, 1600, 25))
 plot(GSg, which=c(1,99), map.xlim=c(-85,-(64+13/60)))
 
-## ----fig.cap="**Figure 5.** World in Winkel Tripel projection, with the `section` profile sites indicated.", fig.width=4, fig.height=2.6, dpi=72----
+## ----fig.cap="**Figure 5.** World in Robinson projection, with the `section` profile sites indicated.", fig.width=4, fig.height=2.6, dpi=72----
 library(oce)
 data(coastlineWorld)
 par(mar=rep(0, 4))
-mapPlot(coastlineWorld, projection="+proj=wintri", col="lightgray")
+mapPlot(coastlineWorld, projection="+proj=robin", col="lightgray")
 data(section)
 lon <- section[["longitude", "byStation"]]
 lat <- section[["latitude", "byStation"]]
@@ -69,11 +106,6 @@ mapLines(lon, lat, col='red', cex=0.5)
 data(coastlineWorld)
 par(mar=rep(1, 4))
 
-## ----fig.keep="none"-----------------------------------------------------
-mapPlot(coastlineWorld, projection="+proj=moll") # Molleweide
-mapPlot(coastlineWorld, projection="+proj=eck4") # Eckert IV
-mapPlot(coastlineWorld, projection="+proj=robin") # Robinson
-
 ## ----fig.cap="**Figure 6.** World bathymetry in Molleweide projection.", fig.width=5, fig.height=2.7, dpi=72, dev.args=list(pointsize=10)----
 par(mar=c(1.5, 1, 1.5, 1))
 data(topoWorld)
@@ -99,22 +131,50 @@ mapPlot(coastlineWorld, projection="+proj=merc",
 mapPlot(coastlineWorld, projection="+proj=aea +lat_1=30 +lat_2=70 +lon_0=-40",
         longitudelim=lonlim, latitudelim=latlim)
 
-## ----fig.cap="**Figure 8.** Arctic coastlines in stereopolar projection.", fig.width=5, fig.height=5, dpi=72----
+## ----fig.cap="**Figure 8.** Arctic coastlines in stereopolar projection.", fig.width=3, fig.height=3, dpi=72----
 par(mar=c(2, 2, 1, 1))
 mapPlot(coastlineWorld, projection="+proj=stere +lat_0=90",
         longitudelim=c(-80,0), latitudelim=c(70, 110))
 
-## ----fig.cap="**Figure 9.** Sea-level timeseries measured in 2003 in Halifax Harbour.", fig.width=7, fig.height=5, dpi=72, dev.args=list(pointsize=16)----
+## ----fig.cap="**Figure 9.** Sea-level timeseries measured in 2003 in Halifax Harbour.", fig.width=5, fig.height=4, dpi=72, dev.args=list(pointsize=16)----
 library(oce)
 data(sealevel)
 plot(sealevel)
 
-## ----fig.cap="**Figure 10.** Measurements made with a bottom-mounted ADP in the St Lawrence Estuary. The line near the surface indicates pressure measured by the ADP.", fig.width=5, fig.height=2, dpi=72----
+## ----fig.cap="**Figure 10.** Measurements made with a bottom-mounted ADP in the St Lawrence Estuary. The line near the surface indicates pressure measured by the ADP.", fig.width=4, fig.height=2, dpi=72----
 library(oce)
 data(adp)
 plot(adp, which=1)
 lines(adp[['time']], adp[['pressure']], lwd=2)
 
+## ------------------------------------------------------------------------
+data(section)
+stn <- section[["station", 100]]
+head(stn[["salinityFlag"]])
+
+## ------------------------------------------------------------------------
+# fake second datum
+stn[["salinity"]][2] <- -999
+
+## ------------------------------------------------------------------------
+stn[["salinityFlag"]] <- ifelse(stn[["salinity"]] < 0, 3, stn[["salinityFlag"]])
+
+## ------------------------------------------------------------------------
+head(stn[["salinityFlag"]])
+
+## ------------------------------------------------------------------------
+stn2 <- stn
+stn2[["salinity"]] <- ifelse(stn2[["salinityFlag"]]!=2, NA, stn2[["salinity"]])
+head(stn2[["salinityFlag"]])
+
+## ------------------------------------------------------------------------
+stn3 <- stn
+stn3[["salinity"]][2] <- -999
+stn3 <- handleFlags(stn3, list(salinity=c(1,3:9)))
+
+## ------------------------------------------------------------------------
+head(data.frame(stnS=stn[["salinity"]], stn2S=stn2[["salinity"]], stn3S=stn3[["salinity"]]))
+
 ## ----fig.keep="none"-----------------------------------------------------
 library(oce)
 Sys.setenv(LANGUAGE="fr")
